//
//  Extensions.swift
//  SampleApp
//
//  Created by Michael Abadi on 13/07/20.
//  Copyright © 2020 David Zhang. All rights reserved.
//

import Foundation
import AmitySDK
import UIKit

extension Encodable {
    var dictionary: [String: Any]? {
        guard let data = try? JSONEncoder().encode(self) else { return nil }
        return (try? JSONSerialization.jsonObject(with: data, options: .allowFragments)).flatMap { $0 as? [String: Any] }
    }
}

extension AmityDataStatus {
    
    var description: String {
        switch self {
        case .local:
            return "Local"
        case .error:
            return "Error"
        case .fresh:
            return "Fresh"
        case .notExist:
            return "Not Exists"
        default:
            return "Unknown"
        }
    }
    
}

extension AmitySyncState: CustomStringConvertible {
    
    public var description: String {
        switch self {
        case .default:
            return "AmitySyncState.default"
        case .error:
            return "AmitySyncState.error"
        case .synced:
            return "AmitySyncState.synced"
        case .syncing:
            return "AmitySyncState.syncing"
        default:
            return "AmitySyncState.unknown"
        }
    }
    
}

extension AmitySyncState {
    
    func symbolImage() -> UIImage? {
        switch self {
        case .default, .syncing:
            return UIImage(systemName: "arrow.up")
        case .synced:
            return UIImage(systemName: "checkmark")
        case .error:
            return UIImage(named: "error")
        @unknown default:
            return UIImage(named: "error")
        }
    }
    
    func tintColor() -> UIColor? {
        switch self {
        case .default, .syncing:
            return UIColor(named: "AmityGray")
        case .synced:
            return UIColor(named: "AmityGreen")
        case .error:
            return UIColor(named: "AmityRed")
        @unknown default:
            return UIColor(named: "AmityRed")
        }
    }
    
}

extension AmityMediaSize {
    
    var description: String {
        switch self {
        case .full:
            return "Full"
        case .large:
            return "Large"
        case .medium:
            return "Medium"
        case .small:
            return "Small"
        default:
            return "Not Available"
        }
    }
    
}
